@@ -11,6 +11,10 @@ from typing import Optional, Literal
 from .errors import UnsupportedSeleniumDriverError, UnableToDownloadSeleniumDriverError
 DriverType = Literal['chrome', 'firefox']
 
+def get_chrome_version() -> Optional[str]:
+    return os.popen('google-chrome-stable --version | cut -d " " -f3 | cut -d "." -f1-3').read().strip()
+
+
 def _driver_name(driver_type: str, platform_str: str, arch: str, version: str) -> str:
     return f"{driver_type}_{version}_{platform_str}_{arch}"
 
@@ -43,6 +47,13 @@ def download_driver(driver_type: DriverType, download_path: Path, version: Optio
     if driver_type_str == 'firefox':
         executable_path = _download_geckodriver(download_path, version, os_name, arch)
     elif driver_type_str == 'chrome':
+        if version is None:
+            chrome_version = get_chrome_version()
+            if chrome_version:
+                version = '.'.join(chrome_version.split('.')[:3])
+                print(f"Detected Chrome version: {version}")
+            else:
+                print("Warning: Could not detect Chrome version. Proceeding to download latest chromedriver.")
         executable_path = _download_chromedriver(download_path, version, os_name, arch)
     else:
         raise UnsupportedSeleniumDriverError(driver_type)
@@ -128,8 +139,9 @@ def _download_chromedriver(download_path: Path, version: Optional[str], os_name:
         all_versions_data = response.json()
         
         target_version_info = None
+        all_versions_data['versions'].sort(key=lambda v: list(map(int, v['version'].split('.'))), reverse=True)
         for v_info in all_versions_data['versions']:
-            if v_info['version'] == version:
+            if v_info['version'].startswith(version):
                 target_version_info = v_info
                 break
         
@@ -205,8 +217,14 @@ def _download_and_extract(url: str, download_path: Path, driver_name: str, filen
     if archive_name.endswith('.zip'):
         with zipfile.ZipFile(archive_path, 'r') as zip_ref:
             # Find the executable member in the zip
+            if driver_name == 'chromedriver':
+                required_filename = 'chromedriver.exe' if sys.platform.startswith('win') else 'chromedriver'
+            else:
+                required_filename = 'geckodriver.exe' if sys.platform.startswith('win') else 'geckodriver'
             for member_info in zip_ref.infolist():
-                if member_info.filename.endswith(executable_name) and not member_info.is_dir():
+                zip_filename = member_info.filename.split('/')[-1]
+                
+                if zip_filename == required_filename and not member_info.is_dir():
                     # Extract the file directly into the target path, not a sub-folder
                     member_info.filename = os.path.basename(member_info.filename)
                     zip_ref.extract(member_info, download_path)
@@ -227,7 +245,7 @@ def _download_and_extract(url: str, download_path: Path, driver_name: str, filen
         os.chmod(final_path, current_permissions | stat.S_IEXEC)
 
     # Clean up the downloaded archive
-    os.remove(archive_path)
+    #os.remove(archive_path)
     if not final_path or not final_path.exists():
         raise UnableToDownloadSeleniumDriverError(driver_name, "Extraction failed or executable not found.")
     # move file to desired filename
@@ -236,3 +254,4 @@ def _download_and_extract(url: str, download_path: Path, driver_name: str, filen
         final_path.rename(new_path)
         final_path = new_path
     return final_path
+
