@@ -23,7 +23,7 @@ def selenium_driver(driver_type: DriverType, version: Optional[str] = None) -> p
     selenium_download_path = pathlib.Path(selenium_download_path_str)
     
     download_file = download_driver(driver_type, selenium_download_path, version)
-    if driver_type == 'chrome' and not os.access(download_file, os.X_OK):
+    if driver_type == 'chrome':
         # make executable
         download_file.chmod(download_file.stat().st_mode | 0o111)
         
@@ -35,7 +35,7 @@ def selenium_driver(driver_type: DriverType, version: Optional[str] = None) -> p
         if headless:
             options.add_argument('--headless=new')
         return webdriver.Chrome(service=service, options=options)
-    elif driver_type == 'firefox' and not os.access(download_file, os.X_OK):
+    elif driver_type == 'firefox':
         # make executable
         download_file.chmod(download_file.stat().st_mode | 0o111)
         
